@@ -128,6 +128,8 @@ GResource *sendto_get_resource (void)
 /* GLIB - Library of useful routines for C programming
  * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
  *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -220,6 +222,7 @@ GResource *sendto_get_resource (void)
 #define G_MSVC_CTOR(_func,_sym_prefix) \
   static void _func(void); \
   extern int (* _array ## _func)(void);              \
+  int _func ## _wrapper(void);              \
   int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
   __pragma(section(".CRT$XCU",read)) \
@@ -228,6 +231,7 @@ GResource *sendto_get_resource (void)
 #define G_MSVC_DTOR(_func,_sym_prefix) \
   static void _func(void); \
   extern int (* _array ## _func)(void);              \
+  int _func ## _constructor(void);              \
   int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
    __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
   __pragma(section(".CRT$XCU",read)) \
